aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--src/rpc/core_rpc_server.cpp13
1 files changed, 8 insertions, 5 deletions
diff --git a/src/rpc/core_rpc_server.cpp b/src/rpc/core_rpc_server.cpp
index f31732f49..5bf500733 100644
--- a/src/rpc/core_rpc_server.cpp
+++ b/src/rpc/core_rpc_server.cpp
@@ -425,12 +425,15 @@ namespace cryptonote
if (req.decode_as_json)
res.txs_as_json.push_back(e.as_json);
- // output indices too
- bool r = m_core.get_tx_outputs_gindexs(tx_hash, e.output_indices);
- if (!r)
+ // output indices too if not in pool
+ if (pool_tx_hashes.find(tx_hash) == pool_tx_hashes.end())
{
- res.status = "Failed";
- return false;
+ bool r = m_core.get_tx_outputs_gindexs(tx_hash, e.output_indices);
+ if (!r)
+ {
+ res.status = "Failed";
+ return false;
+ }
}
}